@@ -6,18 +6,9 @@ from __future__ import annotations
 
 INCLUDES = """
 #include <openssl/x509v3.h>
-
-/*
- * This is part of a work-around for the difficulty cffi has in dealing with
- * `STACK_OF(foo)` as the name of a type.  We invent a new, simpler name that
- * will be an alias for this type and use the alias throughout.  This works
- * together with another opaque typedef for the same name in the TYPES section.
- * Note that the result is an opaque type.
- */
 """
 
 TYPES = """
-typedef ... EXTENDED_KEY_USAGE;
 typedef ... CONF;
 
 typedef struct {
@@ -30,7 +21,7 @@ static const int GEN_EMAIL;
 static const int GEN_DNS;
 static const int GEN_URI;
 
-typedef struct stack_st_GENERAL_NAME GENERAL_NAMES;
+typedef ... GENERAL_NAMES;
 
 /* Only include the one union element used by pyOpenSSL. */
 typedef struct {
@@ -54,8 +45,8 @@ X509_EXTENSION *X509V3_EXT_nconf(CONF *, X509V3_CTX *, const char *,
 
 void X509V3_set_ctx_nodb(X509V3_CTX *);
 
-int sk_GENERAL_NAME_num(struct stack_st_GENERAL_NAME *);
-GENERAL_NAME *sk_GENERAL_NAME_value(struct stack_st_GENERAL_NAME *, int);
+int sk_GENERAL_NAME_num(GENERAL_NAMES *);
+GENERAL_NAME *sk_GENERAL_NAME_value(GENERAL_NAMES *, int);
 """
 
 CUSTOMIZATIONS = """
